==> svm-19.0.0-sources.jar: com/oracle/svm/core/graal/nodes/DeoptTestNode.java <==
/*
 * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.graal.nodes;

import org.graalvm.compiler.core.common.type.StampFactory;
import org.graalvm.compiler.graph.NodeClass;
import org.graalvm.compiler.nodeinfo.InputType;
import org.graalvm.compiler.nodeinfo.NodeCycles;
import org.graalvm.compiler.nodeinfo.NodeInfo;
import org.graalvm.compiler.nodeinfo.NodeSize;
import org.graalvm.compiler.nodes.DeoptimizingNode;
import org.graalvm.compiler.nodes.FixedWithNextNode;
import org.graalvm.compiler.nodes.FrameState;
import org.graalvm.compiler.nodes.memory.MemoryCheckpoint;
import org.graalvm.compiler.nodes.spi.Lowerable;
import org.graalvm.compiler.nodes.spi.LoweringTool;
import org.graalvm.word.LocationIdentity;

import com.oracle.svm.core.deopt.DeoptTester;

/**
 * Inserted for deoptimization stress test. This node is lowered to a runtime call which calls
 * {@link DeoptTester#deoptTest()}.
 */
@NodeInfo(allowedUsageTypes = InputType.Memory, cycles = NodeCycles.CYCLES_IGNORED, size = NodeSize.SIZE_IGNORED)
public final class DeoptTestNode extends FixedWithNextNode implements Lowerable, DeoptimizingNode.DeoptAfter, MemoryCheckpoint.Single {
    public static final NodeClass<DeoptTestNode> TYPE = NodeClass.create(DeoptTestNode.class);

    @OptionalInput(InputType.State) protected FrameState deoptState;

    public DeoptTestNode() {
        super(TYPE, StampFactory.forVoid());
    }

    @Override
    public boolean canDeoptimize() {
        return true;
    }

    @Override
    public boolean hasSideEffect() {
        return true;
    }

    @Override
    public FrameState stateAfter() {
        return deoptState;
    }

    @Override
    public void setStateAfter(FrameState f) {
        updateUsages(deoptState, f);
        deoptState = f;
    }

    @Override
    public void lower(LoweringTool tool) {
        tool.getLowerer().lower(this, tool);
    }

    @Override
    public LocationIdentity getLocationIdentity() {
        return LocationIdentity.any();
    }
}

==> svm-19.3.6-sources.jar: com/oracle/svm/core/graal/nodes/DeoptTestNode.java <==
/*
 * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.graal.nodes;

import org.graalvm.compiler.core.common.type.StampFactory;
import org.graalvm.compiler.graph.NodeClass;
import org.graalvm.compiler.nodeinfo.InputType;
import org.graalvm.compiler.nodeinfo.NodeCycles;
import org.graalvm.compiler.nodeinfo.NodeInfo;
import org.graalvm.compiler.nodeinfo.NodeSize;
import org.graalvm.compiler.nodes.DeoptimizingNode;
import org.graalvm.compiler.nodes.FixedWithNextNode;
import org.graalvm.compiler.nodes.FrameState;
import org.graalvm.compiler.nodes.memory.MemoryCheckpoint;
import org.graalvm.compiler.nodes.spi.Lowerable;
import org.graalvm.compiler.nodes.spi.LoweringTool;
import org.graalvm.word.LocationIdentity;

import com.oracle.svm.core.graal.snippets.DeoptTester;

/**
 * Inserted for deoptimization stress test. This node is lowered to a runtime call which calls
 * {@link DeoptTester#deoptTest()}.
 */
@NodeInfo(allowedUsageTypes = InputType.Memory, cycles = NodeCycles.CYCLES_IGNORED, size = NodeSize.SIZE_IGNORED)
public final class DeoptTestNode extends FixedWithNextNode implements Lowerable, DeoptimizingNode.DeoptAfter, MemoryCheckpoint.Single {
    public static final NodeClass<DeoptTestNode> TYPE = NodeClass.create(DeoptTestNode.class);

    @OptionalInput(InputType.State) protected FrameState deoptState;

    public DeoptTestNode() {
        super(TYPE, StampFactory.forVoid());
    }

    @Override
    public boolean canDeoptimize() {
        return true;
    }

    @Override
    public boolean hasSideEffect() {
        return true;
    }

    @Override
    public FrameState stateAfter() {
        return deoptState;
    }

    @Override
    public void setStateAfter(FrameState f) {
        updateUsages(deoptState, f);
        deoptState = f;
    }

    @Override
    public void lower(LoweringTool tool) {
        tool.getLowerer().lower(this, tool);
    }

    @Override
    public LocationIdentity getKilledLocationIdentity() {
        return LocationIdentity.any();
    }
}
